#!/bin/env python
## @file    add_function_definition.py
## @brief   Example creating and using a function definition
## @author  Frank T. Bergmann
##
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->


import libsbml
import sys
import os

def create_sbml_file(file_name):
    """ 
        Simple function that creates a new SBML model 'model1' with a non constant parameter x
    """
    doc = libsbml.SBMLDocument()
    model = doc.createModel()
    model.setId('model1')

    x = model.createParameter()
    x.setId('x')
    x.setValue(0)
    x.setConstant(False)

    libsbml.writeSBMLToFile(doc, file_name)


def add_function_defintion(model, id, function):
    #type: (libsbml.Model, str, str)
    """
        this function adds a new function definition to the given sbml model
    """

    if model.getFunctionDefinition(id):
        raise ValueError('the model already has a function definition with id %s' % id)
    fun = model.createFunctionDefinition()
    fun.setId(id)

    math = libsbml.parseL3Formula(function)
    if not math: 
        raise ValueError('the formula could not be parsed')
    fun.setMath(math)

def add_assignment(model, parameter_id, formula):
    #type: (libsbml.Model, str, str)
    """
        this function adds an assignment rule to the given parameter
    """
    if not model.getParameter(parameter_id):
        raise ValueError('the model has no parameter %s' % parameter_id)

    rule = model.createAssignmentRule()
    rule.setVariable(parameter_id)
    
    math = libsbml.parseL3Formula(formula)
    if not math: 
        raise ValueError('the formula could not be parsed')
    
    rule.setMath(math)


if __name__ == "__main__":

    # create a test model if none exists
    if not os.path.exists('test.xml'):
        create_sbml_file('test.xml')

    # read in the test model 
    doc = libsbml.readSBMLFromFile('test.xml')

    # bail if it contained errors
    if doc.getNumErrors(libsbml.LIBSBML_SEV_ERROR) > 0: 
        doc.printErrors()
        sys.exit(1)

    model = doc.getModel()

    # add a function definiton 'f(x) = sin(x)' to the model
    add_function_defintion(model, 'f', 'lambda(x, sin(x))')

    # add an assignment to model: x = sin(time)
    add_assignment(model, 'x', 'f(time)')

    # validate the model and bail if it contains errors now
    doc.checkConsistency()
    if doc.getNumErrors(libsbml.LIBSBML_SEV_ERROR) > 0: 
        doc.printErrors()
        sys.exit(2)

    # write model to the file
    libsbml.writeSBMLToFile(doc, 'test.xml')



#
# @file    TestAlgebraicRule.py
# @brief   AlgebraicRule unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Ben Bornstein 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestAlgebraicRule.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestAlgebraicRule(unittest.TestCase):

  global AR
  AR = None

  def setUp(self):
    self.AR = libsbml.AlgebraicRule(2,4)
    if (self.AR == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.AR ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_AlgebraicRule_create(self):
    self.assertTrue( self.AR.getTypeCode() == libsbml.SBML_ALGEBRAIC_RULE )
    self.assertTrue( self.AR.getMetaId() == "" )
    self.assertTrue( self.AR.getNotes() == None )
    self.assertTrue( self.AR.getAnnotation() == None )
    self.assertTrue( self.AR.getFormula() == "" )
    self.assertTrue( self.AR.getMath() == None )
    pass  

  def test_AlgebraicRule_createWithFormula(self):
    ar = libsbml.AlgebraicRule(2,4)
    ar.setFormula( "1 + 1")
    self.assertTrue( ar.getTypeCode() == libsbml.SBML_ALGEBRAIC_RULE )
    self.assertTrue( ar.getMetaId() == "" )
    math = ar.getMath()
    self.assertTrue( math != None )
    formula = libsbml.formulaToString(math)
    self.assertTrue( formula != None )
    self.assertTrue((  "1 + 1" == formula ))
    self.assertTrue(( formula == ar.getFormula() ))
    _dummyList = [ ar ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_AlgebraicRule_createWithMath(self):
    math = libsbml.parseFormula("1 + 1")
    ar = libsbml.AlgebraicRule(2,4)
    ar.setMath(math)
    self.assertTrue( ar.getTypeCode() == libsbml.SBML_ALGEBRAIC_RULE )
    self.assertTrue( ar.getMetaId() == "" )
    self.assertTrue((  "1 + 1" == ar.getFormula() ))
    self.assertTrue( ar.getMath() != math )
    _dummyList = [ ar ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_AlgebraicRule_createWithNS(self):
    xmlns = libsbml.XMLNamespaces()
    xmlns.add( "http://www.sbml.org", "testsbml")
    sbmlns = libsbml.SBMLNamespaces(2,3)
    sbmlns.addNamespaces(xmlns)
    r = libsbml.AlgebraicRule(sbmlns)
    self.assertTrue( r.getTypeCode() == libsbml.SBML_ALGEBRAIC_RULE )
    self.assertTrue( r.getMetaId() == "" )
    self.assertTrue( r.getNotes() == None )
    self.assertTrue( r.getAnnotation() == None )
    self.assertTrue( r.getLevel() == 2 )
    self.assertTrue( r.getVersion() == 3 )
    self.assertTrue( r.getNamespaces() != None )
    self.assertTrue( r.getNamespaces().getLength() == 2 )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_AlgebraicRule_free_NULL(self):
    _dummyList = [ None ]; _dummyList[:] = []; del _dummyList
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestAlgebraicRule))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#
# @file    TestUnit_newSetters.py
# @brief   Unit unit tests for new set function API
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestUnit_newSetters.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestUnit_newSetters(unittest.TestCase):

  global U
  U = None

  def setUp(self):
    self.U = libsbml.Unit(1,2)
    if (self.U == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.U ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Unit_removeScale(self):
    i = self.U.setScale(2)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.U.getScale() == 2 )
    i = libsbml.Unit.removeScale(self.U)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.U.getScale() == 0 )
    self.assertTrue( self.U.getMultiplier() == 100 )
    pass  

  def test_Unit_setExponent1(self):
    i = self.U.setExponent(2)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.U.getExponent() == 2 )
    pass  

  def test_Unit_setExponent2(self):
    i = self.U.setExponent(2.0)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.U.getExponent() == 2 )
    pass  

  def test_Unit_setExponent3(self):
    i = self.U.setExponent(2.2)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( self.U.getExponent() == 1 )
    pass  

  def test_Unit_setKind1(self):
    i = self.U.setKind(libsbml.UnitKind_forName("cell"))
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertEqual( False, self.U.isSetKind() )
    pass  

  def test_Unit_setKind2(self):
    i = self.U.setKind(libsbml.UnitKind_forName("litre"))
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.U.isSetKind() )
    pass  

  def test_Unit_setMultiplier1(self):
    i = self.U.setMultiplier(2)
    self.assertTrue( i == libsbml.LIBSBML_UNEXPECTED_ATTRIBUTE )
    self.assertTrue( self.U.getMultiplier() == 2 )
    pass  

  def test_Unit_setMultiplier2(self):
    c = libsbml.Unit(2,2)
    i = c.setMultiplier(4)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( c.getMultiplier() == 4 )
    _dummyList = [ c ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Unit_setOffset1(self):
    i = self.U.setOffset(2.0)
    self.assertTrue( i == libsbml.LIBSBML_UNEXPECTED_ATTRIBUTE )
    self.assertTrue( self.U.getOffset() == 0 )
    pass  

  def test_Unit_setOffset2(self):
    U1 = libsbml.Unit(2,1)
    i = U1.setOffset(2.0)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( U1.getOffset() == 2 )
    pass  

  def test_Unit_setScale1(self):
    i = self.U.setScale(2)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.U.getScale() == 2 )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestUnit_newSetters))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#
# @file    TestSBase.py
# @brief   SBase unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Ben Bornstein
#
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestSBase.cpp
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
#
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml

def wrapString(s):
  return s
  pass


class TestSBase(unittest.TestCase):

  global S
  S = None

  def setUp(self):
    self.S = libsbml.Model(2,4)
    if (self.S == None):
      pass
    pass

  def tearDown(self):
    self.S = None
    pass

  def test_SBase_CVTerms(self):
    cv = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv.setBiologicalQualifierType(libsbml.BQB_IS)
    cv.addResource( "foo")
    self.assertTrue( self.S.getNumCVTerms() == 0 )
    #self.assertTrue( self.S.getCVTerms() == None )
    self.assertTrue( len(self.S.getCVTerms()) == 0 )
    self.S.setMetaId( "_id")
    self.S.addCVTerm(cv)
    self.assertTrue( self.S.getNumCVTerms() == 1 )
    #self.assertTrue( self.S.getCVTerms() != None )
    self.assertTrue( len(self.S.getCVTerms()) == 1 )
    self.assertTrue( self.S.getCVTerm(0) != cv )
    _dummyList = [ cv ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_addCVTerms(self):
    cv = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv.setBiologicalQualifierType(libsbml.BQB_ENCODES)
    cv.addResource( "foo")
    self.S.setMetaId( "sbase1")
    self.S.addCVTerm(cv)
    self.assertTrue( self.S.getNumCVTerms() == 1 )
    #self.assertTrue( self.S.getCVTerms() != None )
    self.assertTrue( len(self.S.getCVTerms()) == 1 )
    res = self.S.getCVTerm(0).getResources()
    self.assertTrue((  "foo" == res.getValue(0) ))
    cv1 = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv1.setBiologicalQualifierType(libsbml.BQB_IS)
    cv1.addResource( "bar")
    self.S.addCVTerm(cv1)
    self.assertTrue( self.S.getNumCVTerms() == 2 )
    cv2 = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv2.setBiologicalQualifierType(libsbml.BQB_IS)
    cv2.addResource( "bar1")
    self.S.addCVTerm(cv2)
    self.assertTrue( self.S.getNumCVTerms() == 2 )
    res = self.S.getCVTerm(1).getResources()
    self.assertTrue( res.getLength() == 2 )
    self.assertTrue((  "bar" == res.getValue(0) ))
    self.assertTrue((  "bar1" == res.getValue(1) ))
    cv4 = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv4.setBiologicalQualifierType(libsbml.BQB_IS)
    cv4.addResource( "bar1")
    self.S.addCVTerm(cv4)
    self.assertTrue( self.S.getNumCVTerms() == 2 )
    res = self.S.getCVTerm(1).getResources()
    self.assertTrue( res.getLength() == 2 )
    self.assertTrue((  "bar" == res.getValue(0) ))
    self.assertTrue((  "bar1" == res.getValue(1) ))
    cv5 = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv5.setBiologicalQualifierType(libsbml.BQB_HAS_PART)
    cv5.addResource( "bar1")
    self.S.addCVTerm(cv5)
    self.assertTrue( self.S.getNumCVTerms() == 2 )
    res = self.S.getCVTerm(1).getResources()
    self.assertTrue( res.getLength() == 2 )
    self.assertTrue((  "bar" == res.getValue(0) ))
    self.assertTrue((  "bar1" == res.getValue(1) ))
    _dummyList = [ cv ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ cv2 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ cv1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ cv4 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_appendNotes(self):
    triple = libsbml.XMLTriple("p", "", "")
    att = libsbml.XMLAttributes()
    ns = libsbml.XMLNamespaces()
    ns.add( "http://www.w3.org/1999/xhtml", "")
    token4 = libsbml.XMLToken("This is my text")
    node4 = libsbml.XMLNode(token4)
    token5 = libsbml.XMLToken("This is additional text")
    node5 = libsbml.XMLNode(token5)
    token = libsbml.XMLToken(triple,att,ns)
    node = libsbml.XMLNode(token)
    node.addChild(node4)
    self.S.setNotes(node)
    self.assertTrue( self.S.isSetNotes() == True )
    token1 = libsbml.XMLToken(triple,att,ns)
    node1 = libsbml.XMLNode(token1)
    node1.addChild(node5)
    self.S.appendNotes(node1)
    self.assertTrue( self.S.isSetNotes() == True )
    node2 = self.S.getNotes()
    self.assertTrue( node2.getNumChildren() == 2 )
    self.assertTrue((  "p" == node2.getChild(0).getName() ))
    self.assertTrue( node2.getChild(0).getNumChildren() == 1 )
    self.assertTrue((  "p" == node2.getChild(1).getName() ))
    self.assertTrue( node2.getChild(1).getNumChildren() == 1 )
    chars1 = node2.getChild(0).getChild(0).getCharacters()
    chars2 = node2.getChild(1).getChild(0).getCharacters()
    self.assertTrue((  "This is my text" == chars1 ))
    self.assertTrue((  "This is additional text" == chars2 ))
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node1 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_appendNotes1(self):
    att = libsbml.XMLAttributes()
    ns = libsbml.XMLNamespaces()
    ns.add( "http://www.w3.org/1999/xhtml", "")
    html_triple = libsbml.XMLTriple("html", "", "")
    head_triple = libsbml.XMLTriple("head", "", "")
    title_triple = libsbml.XMLTriple("title", "", "")
    body_triple = libsbml.XMLTriple("body", "", "")
    p_triple = libsbml.XMLTriple("p", "", "")
    html_token = libsbml.XMLToken(html_triple,att,ns)
    head_token = libsbml.XMLToken(head_triple,att)
    title_token = libsbml.XMLToken(title_triple,att)
    body_token = libsbml.XMLToken(body_triple,att)
    p_token = libsbml.XMLToken(p_triple,att)
    text_token = libsbml.XMLToken("This is my text")
    html_node = libsbml.XMLNode(html_token)
    head_node = libsbml.XMLNode(head_token)
    title_node = libsbml.XMLNode(title_token)
    body_node = libsbml.XMLNode(body_token)
    p_node = libsbml.XMLNode(p_token)
    text_node = libsbml.XMLNode(text_token)
    text_token1 = libsbml.XMLToken("This is more text")
    html_node1 = libsbml.XMLNode(html_token)
    head_node1 = libsbml.XMLNode(head_token)
    title_node1 = libsbml.XMLNode(title_token)
    body_node1 = libsbml.XMLNode(body_token)
    p_node1 = libsbml.XMLNode(p_token)
    text_node1 = libsbml.XMLNode(text_token1)
    p_node.addChild(text_node)
    body_node.addChild(p_node)
    head_node.addChild(title_node)
    html_node.addChild(head_node)
    html_node.addChild(body_node)
    p_node1.addChild(text_node1)
    body_node1.addChild(p_node1)
    head_node1.addChild(title_node1)
    html_node1.addChild(head_node1)
    html_node1.addChild(body_node1)
    self.S.setNotes(html_node)
    self.S.appendNotes(html_node1)
    notes = self.S.getNotes()
    self.assertTrue((  "notes" == notes.getName() ))
    self.assertTrue( notes.getNumChildren() == 1 )
    child = notes.getChild(0)
    self.assertTrue((  "html" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child = child.getChild(1)
    self.assertTrue((  "body" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child1 = child.getChild(0)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is my text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    child1 = child.getChild(1)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is more text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    _dummyList = [ att ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ns ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node1 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_appendNotes2(self):
    att = libsbml.XMLAttributes()
    ns = libsbml.XMLNamespaces()
    ns.add( "http://www.w3.org/1999/xhtml", "")
    html_triple = libsbml.XMLTriple("html", "", "")
    head_triple = libsbml.XMLTriple("head", "", "")
    title_triple = libsbml.XMLTriple("title", "", "")
    body_triple = libsbml.XMLTriple("body", "", "")
    p_triple = libsbml.XMLTriple("p", "", "")
    html_token = libsbml.XMLToken(html_triple,att,ns)
    head_token = libsbml.XMLToken(head_triple,att)
    title_token = libsbml.XMLToken(title_triple,att)
    body_token = libsbml.XMLToken(body_triple,att)
    p_token = libsbml.XMLToken(p_triple,att)
    text_token = libsbml.XMLToken("This is my text")
    html_node = libsbml.XMLNode(html_token)
    head_node = libsbml.XMLNode(head_token)
    title_node = libsbml.XMLNode(title_token)
    body_node = libsbml.XMLNode(body_token)
    p_node = libsbml.XMLNode(p_token)
    text_node = libsbml.XMLNode(text_token)
    body_token1 = libsbml.XMLToken(body_triple,att,ns)
    text_token1 = libsbml.XMLToken("This is more text")
    body_node1 = libsbml.XMLNode(body_token1)
    p_node1 = libsbml.XMLNode(p_token)
    text_node1 = libsbml.XMLNode(text_token1)
    p_node.addChild(text_node)
    body_node.addChild(p_node)
    head_node.addChild(title_node)
    html_node.addChild(head_node)
    html_node.addChild(body_node)
    p_node1.addChild(text_node1)
    body_node1.addChild(p_node1)
    self.S.setNotes(html_node)
    self.S.appendNotes(body_node1)
    notes = self.S.getNotes()
    self.assertTrue((  "notes" == notes.getName() ))
    self.assertTrue( notes.getNumChildren() == 1 )
    child = notes.getChild(0)
    self.assertTrue((  "html" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child = child.getChild(1)
    self.assertTrue((  "body" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child1 = child.getChild(0)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is my text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    child1 = child.getChild(1)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is more text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    _dummyList = [ att ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ns ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node1 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_appendNotes3(self):
    att = libsbml.XMLAttributes()
    ns = libsbml.XMLNamespaces()
    ns.add( "http://www.w3.org/1999/xhtml", "")
    html_triple = libsbml.XMLTriple("html", "", "")
    head_triple = libsbml.XMLTriple("head", "", "")
    title_triple = libsbml.XMLTriple("title", "", "")
    body_triple = libsbml.XMLTriple("body", "", "")
    p_triple = libsbml.XMLTriple("p", "", "")
    html_token = libsbml.XMLToken(html_triple,att,ns)
    head_token = libsbml.XMLToken(head_triple,att)
    title_token = libsbml.XMLToken(title_triple,att)
    body_token = libsbml.XMLToken(body_triple,att)
    p_token = libsbml.XMLToken(p_triple,att)
    text_token = libsbml.XMLToken("This is my text")
    html_node = libsbml.XMLNode(html_token)
    head_node = libsbml.XMLNode(head_token)
    title_node = libsbml.XMLNode(title_token)
    body_node = libsbml.XMLNode(body_token)
    p_node = libsbml.XMLNode(p_token)
    text_node = libsbml.XMLNode(text_token)
    p_token1 = libsbml.XMLToken(p_triple,att,ns)
    text_token1 = libsbml.XMLToken("This is more text")
    p_node1 = libsbml.XMLNode(p_token1)
    text_node1 = libsbml.XMLNode(text_token1)
    p_node.addChild(text_node)
    body_node.addChild(p_node)
    head_node.addChild(title_node)
    html_node.addChild(head_node)
    html_node.addChild(body_node)
    p_node1.addChild(text_node1)
    self.S.setNotes(html_node)
    self.S.appendNotes(p_node1)
    notes = self.S.getNotes()
    self.assertTrue((  "notes" == notes.getName() ))
    self.assertTrue( notes.getNumChildren() == 1 )
    child = notes.getChild(0)
    self.assertTrue((  "html" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child = child.getChild(1)
    self.assertTrue((  "body" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child1 = child.getChild(0)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is my text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    child1 = child.getChild(1)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is more text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    _dummyList = [ att ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ns ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node1 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_appendNotes4(self):
    att = libsbml.XMLAttributes()
    ns = libsbml.XMLNamespaces()
    ns.add( "http://www.w3.org/1999/xhtml", "")
    html_triple = libsbml.XMLTriple("html", "", "")
    head_triple = libsbml.XMLTriple("head", "", "")
    title_triple = libsbml.XMLTriple("title", "", "")
    body_triple = libsbml.XMLTriple("body", "", "")
    p_triple = libsbml.XMLTriple("p", "", "")
    html_token = libsbml.XMLToken(html_triple,att,ns)
    head_token = libsbml.XMLToken(head_triple,att)
    title_token = libsbml.XMLToken(title_triple,att)
    body_token = libsbml.XMLToken(body_triple,att)
    p_token = libsbml.XMLToken(p_triple,att)
    body_token1 = libsbml.XMLToken(body_triple,att,ns)
    text_token = libsbml.XMLToken("This is my text")
    body_node = libsbml.XMLNode(body_token1)
    p_node = libsbml.XMLNode(p_token)
    text_node = libsbml.XMLNode(text_token)
    text_token1 = libsbml.XMLToken("This is more text")
    html_node1 = libsbml.XMLNode(html_token)
    head_node1 = libsbml.XMLNode(head_token)
    title_node1 = libsbml.XMLNode(title_token)
    body_node1 = libsbml.XMLNode(body_token)
    p_node1 = libsbml.XMLNode(p_token)
    text_node1 = libsbml.XMLNode(text_token1)
    p_node.addChild(text_node)
    body_node.addChild(p_node)
    p_node1.addChild(text_node1)
    body_node1.addChild(p_node1)
    head_node1.addChild(title_node1)
    html_node1.addChild(head_node1)
    html_node1.addChild(body_node1)
    self.S.setNotes(body_node)
    self.S.appendNotes(html_node1)
    notes = self.S.getNotes()
    self.assertTrue((  "notes" == notes.getName() ))
    self.assertTrue( notes.getNumChildren() == 1 )
    child = notes.getChild(0)
    self.assertTrue((  "html" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child = child.getChild(1)
    self.assertTrue((  "body" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child1 = child.getChild(0)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is my text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    child1 = child.getChild(1)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is more text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    _dummyList = [ att ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ns ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node1 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_appendNotes5(self):
    att = libsbml.XMLAttributes()
    ns = libsbml.XMLNamespaces()
    ns.add( "http://www.w3.org/1999/xhtml", "")
    html_triple = libsbml.XMLTriple("html", "", "")
    head_triple = libsbml.XMLTriple("head", "", "")
    title_triple = libsbml.XMLTriple("title", "", "")
    body_triple = libsbml.XMLTriple("body", "", "")
    p_triple = libsbml.XMLTriple("p", "", "")
    html_token = libsbml.XMLToken(html_triple,att,ns)
    head_token = libsbml.XMLToken(head_triple,att)
    title_token = libsbml.XMLToken(title_triple,att)
    body_token = libsbml.XMLToken(body_triple,att)
    p_token = libsbml.XMLToken(p_triple,att)
    p_token1 = libsbml.XMLToken(p_triple,att,ns)
    text_token = libsbml.XMLToken("This is my text")
    p_node = libsbml.XMLNode(p_token1)
    text_node = libsbml.XMLNode(text_token)
    text_token1 = libsbml.XMLToken("This is more text")
    html_node1 = libsbml.XMLNode(html_token)
    head_node1 = libsbml.XMLNode(head_token)
    title_node1 = libsbml.XMLNode(title_token)
    body_node1 = libsbml.XMLNode(body_token)
    p_node1 = libsbml.XMLNode(p_token)
    text_node1 = libsbml.XMLNode(text_token1)
    p_node.addChild(text_node)
    p_node1.addChild(text_node1)
    body_node1.addChild(p_node1)
    head_node1.addChild(title_node1)
    html_node1.addChild(head_node1)
    html_node1.addChild(body_node1)
    self.S.setNotes(p_node)
    self.S.appendNotes(html_node1)
    notes = self.S.getNotes()
    self.assertTrue((  "notes" == notes.getName() ))
    self.assertTrue( notes.getNumChildren() == 1 )
    child = notes.getChild(0)
    self.assertTrue((  "html" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child = child.getChild(1)
    self.assertTrue((  "body" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child1 = child.getChild(0)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is my text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    child1 = child.getChild(1)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is more text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    _dummyList = [ att ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ns ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ html_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ head_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node1 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_appendNotes6(self):
    att = libsbml.XMLAttributes()
    ns = libsbml.XMLNamespaces()
    ns.add( "http://www.w3.org/1999/xhtml", "")
    body_triple = libsbml.XMLTriple("body", "", "")
    p_triple = libsbml.XMLTriple("p", "", "")
    body_token = libsbml.XMLToken(body_triple,att,ns)
    p_token = libsbml.XMLToken(p_triple,att)
    text_token = libsbml.XMLToken("This is my text")
    body_node = libsbml.XMLNode(body_token)
    p_node = libsbml.XMLNode(p_token)
    text_node = libsbml.XMLNode(text_token)
    text_token1 = libsbml.XMLToken("This is more text")
    body_node1 = libsbml.XMLNode(body_token)
    p_node1 = libsbml.XMLNode(p_token)
    text_node1 = libsbml.XMLNode(text_token1)
    p_node.addChild(text_node)
    body_node.addChild(p_node)
    p_node1.addChild(text_node1)
    body_node1.addChild(p_node1)
    self.S.setNotes(body_node)
    self.S.appendNotes(body_node1)
    notes = self.S.getNotes()
    self.assertTrue((  "notes" == notes.getName() ))
    self.assertTrue( notes.getNumChildren() == 1 )
    child = notes.getChild(0)
    self.assertTrue((  "body" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child1 = child.getChild(0)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is my text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    child1 = child.getChild(1)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is more text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    _dummyList = [ att ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ns ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node1 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_appendNotes7(self):
    att = libsbml.XMLAttributes()
    ns = libsbml.XMLNamespaces()
    ns.add( "http://www.w3.org/1999/xhtml", "")
    body_triple = libsbml.XMLTriple("body", "", "")
    p_triple = libsbml.XMLTriple("p", "", "")
    body_token = libsbml.XMLToken(body_triple,att,ns)
    p_token1 = libsbml.XMLToken(p_triple,att,ns)
    text_token = libsbml.XMLToken("This is my text")
    p_token = libsbml.XMLToken(p_triple,att)
    p_node = libsbml.XMLNode(p_token1)
    text_node = libsbml.XMLNode(text_token)
    text_token1 = libsbml.XMLToken("This is more text")
    body_node1 = libsbml.XMLNode(body_token)
    p_node1 = libsbml.XMLNode(p_token)
    text_node1 = libsbml.XMLNode(text_token1)
    p_node.addChild(text_node)
    p_node1.addChild(text_node1)
    body_node1.addChild(p_node1)
    self.S.setNotes(p_node)
    self.S.appendNotes(body_node1)
    notes = self.S.getNotes()
    self.assertTrue((  "notes" == notes.getName() ))
    self.assertTrue( notes.getNumChildren() == 1 )
    child = notes.getChild(0)
    self.assertTrue((  "body" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child1 = child.getChild(0)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is my text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    child1 = child.getChild(1)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is more text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    _dummyList = [ att ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ns ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node1 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_appendNotes8(self):
    att = libsbml.XMLAttributes()
    ns = libsbml.XMLNamespaces()
    ns.add( "http://www.w3.org/1999/xhtml", "")
    body_triple = libsbml.XMLTriple("body", "", "")
    p_triple = libsbml.XMLTriple("p", "", "")
    body_token = libsbml.XMLToken(body_triple,att,ns)
    p_token = libsbml.XMLToken(p_triple,att)
    text_token = libsbml.XMLToken("This is my text")
    body_node = libsbml.XMLNode(body_token)
    p_node = libsbml.XMLNode(p_token)
    text_node = libsbml.XMLNode(text_token)
    p_token1 = libsbml.XMLToken(p_triple,att,ns)
    text_token1 = libsbml.XMLToken("This is more text")
    p_node1 = libsbml.XMLNode(p_token1)
    text_node1 = libsbml.XMLNode(text_token1)
    p_node.addChild(text_node)
    body_node.addChild(p_node)
    p_node1.addChild(text_node1)
    self.S.setNotes(body_node)
    self.S.appendNotes(p_node1)
    notes = self.S.getNotes()
    self.assertTrue((  "notes" == notes.getName() ))
    self.assertTrue( notes.getNumChildren() == 1 )
    child = notes.getChild(0)
    self.assertTrue((  "body" == child.getName() ))
    self.assertTrue( child.getNumChildren() == 2 )
    child1 = child.getChild(0)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is my text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    child1 = child.getChild(1)
    self.assertTrue((  "p" == child1.getName() ))
    self.assertTrue( child1.getNumChildren() == 1 )
    child1 = child1.getChild(0)
    self.assertTrue((  "This is more text" == child1.getCharacters() ))
    self.assertTrue( child1.getNumChildren() == 0 )
    _dummyList = [ att ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ns ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_token1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ body_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p_node1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ text_node1 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_appendNotesString(self):
    notes =  "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is a test note </p>";
    taggednewnotes = wrapString("<notes>\n" + "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is a test note </p>\n" +
    "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes </p>\n" +
    "</notes>")
    taggednewnotes2 = wrapString("<notes>\n" + "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is a test note </p>\n" +
    "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 1</p>\n" +
    "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 2</p>\n" +
    "</notes>")
    newnotes =  "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes </p>";
    newnotes2 = "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 1</p>" + "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 2</p>";
    newnotes3 = wrapString("<notes>\n" + "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes </p>\n" + "</notes>")
    newnotes4 = wrapString("<notes>\n" + "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 1</p>\n" +
    "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 2</p>\n" +
    "</notes>")
    self.S.setNotes(notes)
    self.assertTrue( self.S.isSetNotes() == True )
    self.S.appendNotes(newnotes)
    notes1 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes1 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(newnotes2)
    notes2 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes2 == taggednewnotes2 ))
    self.S.setNotes(notes)
    self.S.appendNotes(newnotes3)
    notes3 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes3 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(newnotes4)
    notes4 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes4 == taggednewnotes2 ))
    pass

  def test_SBase_appendNotesString1(self):
    notes = wrapString("<html xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <head>\n" +
    "    <title/>\n" +
    "  </head>\n" +
    "  <body>\n" +
    "    <p>This is a test note </p>\n" +
    "  </body>\n" +
    "</html>")
    taggednewnotes = wrapString("<notes>\n" +
    "  <html xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <head>\n" +
    "      <title/>\n" +
    "    </head>\n" +
    "    <body>\n" +
    "      <p>This is a test note </p>\n" +
    "      <p>This is more test notes </p>\n" +
    "    </body>\n" +
    "  </html>\n" +
    "</notes>")
    addnotes = wrapString("<html xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <head>\n" +
    "    <title/>\n" +
    "  </head>\n" +
    "  <body>\n" +
    "    <p>This is more test notes </p>\n" +
    "  </body>\n" +
    "</html>")
    addnotes2 = wrapString("<notes>\n" +
    "  <html xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <head>\n" +
    "      <title/>\n" +
    "    </head>\n" +
    "    <body>\n" +
    "      <p>This is more test notes </p>\n" +
    "    </body>\n" +
    "  </html>\n" +
    "</notes>")
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes)
    notes1 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes1 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes2)
    notes2 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes2 == taggednewnotes ))
    pass

  def test_SBase_appendNotesString2(self):
    notes = wrapString("<html xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <head>\n" +
    "    <title/>\n" +
    "  </head>\n" +
    "  <body>\n" +
    "    <p>This is a test note </p>\n" +
    "  </body>\n" +
    "</html>")
    taggednewnotes = wrapString("<notes>\n" +
    "  <html xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <head>\n" +
    "      <title/>\n" +
    "    </head>\n" +
    "    <body>\n" +
    "      <p>This is a test note </p>\n" +
    "      <p>This is more test notes </p>\n" +
    "    </body>\n" +
    "  </html>\n" +
    "</notes>")
    addnotes = wrapString("<body xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <p>This is more test notes </p>\n" + "</body>\n")
    addnotes2 = wrapString("<notes>\n" +
    "  <body xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <p>This is more test notes </p>\n" +
    "  </body>\n" +
    "</notes>")
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes)
    notes1 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes1 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes2)
    notes2 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes2 == taggednewnotes ))
    pass

  def test_SBase_appendNotesString3(self):
    notes = wrapString("<html xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <head>\n" +
    "    <title/>\n" +
    "  </head>\n" +
    "  <body>\n" +
    "    <p>This is a test note </p>\n" +
    "  </body>\n" +
    "</html>")
    taggednewnotes = wrapString("<notes>\n" +
    "  <html xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <head>\n" +
    "      <title/>\n" +
    "    </head>\n" +
    "    <body>\n" +
    "      <p>This is a test note </p>\n" +
    "      <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes </p>\n" +
    "    </body>\n" +
    "  </html>\n" +
    "</notes>")
    taggednewnotes2 = wrapString("<notes>\n" +
    "  <html xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <head>\n" +
    "      <title/>\n" +
    "    </head>\n" +
    "    <body>\n" +
    "      <p>This is a test note </p>\n" +
    "      <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 1</p>\n" +
    "      <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 2</p>\n" +
    "    </body>\n" +
    "  </html>\n" +
    "</notes>")
    addnotes =  "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes </p>\n";
    addnotes2 = "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 1</p>\n" + "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 2</p>";
    addnotes3 = wrapString("<notes>\n" + "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes </p>\n" + "</notes>")
    addnotes4 = wrapString("<notes>\n" + "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 1</p>\n" +
    "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 2</p>\n" +
    "</notes>")
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes)
    notes1 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes1 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes2)
    notes2 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes2 == taggednewnotes2 ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes3)
    notes3 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes3 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes4)
    notes4 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes4 == taggednewnotes2 ))
    pass

  def test_SBase_appendNotesString4(self):
    notes = wrapString("<body xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <p>This is a test note </p>\n" + "</body>")
    taggednewnotes = wrapString("<notes>\n" +
    "  <html xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <head>\n" +
    "      <title/>\n" +
    "    </head>\n" +
    "    <body>\n" +
    "      <p>This is a test note </p>\n" +
    "      <p>This is more test notes </p>\n" +
    "    </body>\n" +
    "  </html>\n" +
    "</notes>")
    addnotes = wrapString("<html xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <head>\n" +
    "    <title/>\n" +
    "  </head>\n" +
    "  <body>\n" +
    "    <p>This is more test notes </p>\n" +
    "  </body>\n" +
    "</html>")
    addnotes2 = wrapString("<notes>\n" +
    "  <html xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <head>\n" +
    "      <title/>\n" +
    "    </head>\n" +
    "    <body>\n" +
    "      <p>This is more test notes </p>\n" +
    "    </body>\n" +
    "  </html>\n" +
    "</notes>")
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes)
    notes1 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes1 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes2)
    notes2 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes2 == taggednewnotes ))
    pass

  def test_SBase_appendNotesString5(self):
    notes =  "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is a test note </p>";
    taggednewnotes = wrapString("<notes>\n" +
    "  <html xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <head>\n" +
    "      <title/>\n" +
    "    </head>\n" +
    "    <body>\n" +
    "      <p xmlns=\"http://www.w3.org/1999/xhtml\">This is a test note </p>\n" +
    "      <p>This is more test notes </p>\n" +
    "    </body>\n" +
    "  </html>\n" +
    "</notes>")
    addnotes = wrapString("<html xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <head>\n" +
    "    <title/>\n" +
    "  </head>\n" +
    "  <body>\n" +
    "    <p>This is more test notes </p>\n" +
    "  </body>\n" +
    "</html>")
    addnotes2 = wrapString("<notes>\n" +
    "  <html xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <head>\n" +
    "      <title/>\n" +
    "    </head>\n" +
    "    <body>\n" +
    "      <p>This is more test notes </p>\n" +
    "    </body>\n" +
    "  </html>\n" +
    "</notes>")
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes)
    notes1 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes1 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes2)
    notes2 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes2 == taggednewnotes ))
    pass

  def test_SBase_appendNotesString6(self):
    notes = wrapString("<body xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <p>This is a test note </p>\n" + "</body>")
    taggednewnotes = wrapString("<notes>\n" +
    "  <body xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <p>This is a test note </p>\n" +
    "    <p>This is more test notes </p>\n" +
    "  </body>\n" +
    "</notes>")
    addnotes = wrapString("<body xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <p>This is more test notes </p>\n" + "</body>")
    addnotes2 = wrapString("<notes>\n" +
    "  <body xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <p>This is more test notes </p>\n" +
    "  </body>\n" +
    "</notes>")
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes)
    notes1 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes1 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes2)
    notes2 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes2 == taggednewnotes ))
    pass

  def test_SBase_appendNotesString7(self):
    notes =  "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is a test note </p>";
    taggednewnotes = wrapString("<notes>\n" +
    "  <body xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <p xmlns=\"http://www.w3.org/1999/xhtml\">This is a test note </p>\n" +
    "    <p>This is more test notes </p>\n" +
    "  </body>\n" +
    "</notes>")
    addnotes = wrapString("<body xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <p>This is more test notes </p>\n" + "</body>")
    addnotes2 = wrapString("<notes>\n" +
    "  <body xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <p>This is more test notes </p>\n" +
    "  </body>\n" +
    "</notes>")
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes)
    notes1 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes1 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes2)
    notes2 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes2 == taggednewnotes ))
    pass

  def test_SBase_appendNotesString8(self):
    notes = wrapString("<body xmlns=\"http://www.w3.org/1999/xhtml\">\n" + "  <p>This is a test note </p>\n" + "</body>")
    taggednewnotes =  ("<notes>\n" +
    "  <body xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <p>This is a test note </p>\n" +
    "    <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes </p>\n" +
    "  </body>\n" +
    "</notes>")
    taggednewnotes2 =  ("<notes>\n" +
    "  <body xmlns=\"http://www.w3.org/1999/xhtml\">\n" +
    "    <p>This is a test note </p>\n" +
    "    <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 1</p>\n" +
    "    <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 2</p>\n" +
    "  </body>\n" +
    "</notes>")
    addnotes =  "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes </p>";
    addnotes2 = "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 1</p>\n" + "<p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 2</p>";
    addnotes3 = wrapString("<notes>\n" +
    "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes </p>\n" +
    "</notes>")
    addnotes4 = wrapString("<notes>\n" +
    "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 1</p>\n" +
    "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is more test notes 2</p>\n" +
    "</notes>")
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes)
    notes1 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes1 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes2)
    notes2 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes2 == taggednewnotes2 ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes3)
    notes3 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes3 == taggednewnotes ))
    self.S.setNotes(notes)
    self.S.appendNotes(addnotes4)
    notes4 = self.S.getNotesString()
    self.assertTrue( self.S.isSetNotes() == True )
    self.assertTrue(( notes4 == taggednewnotes2 ))
    pass

  def test_SBase_getQualifiersFromResources(self):
    cv = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv.setBiologicalQualifierType(libsbml.BQB_ENCODES)
    cv.addResource( "foo")
    self.S.setMetaId( "sbase1")
    self.S.addCVTerm(cv)
    self.assertTrue( self.S.getResourceBiologicalQualifier( "foo") == libsbml.BQB_ENCODES )
    cv1 = libsbml.CVTerm(libsbml.MODEL_QUALIFIER)
    cv1.setModelQualifierType(libsbml.BQM_IS)
    cv1.addResource( "bar")
    self.S.addCVTerm(cv1)
    self.assertTrue( self.S.getResourceModelQualifier( "bar") == libsbml.BQM_IS )
    _dummyList = [ cv ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ cv1 ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_setAnnotation(self):
    token = libsbml.XMLToken("This is a test note")
    node = libsbml.XMLNode(token)
    self.S.setAnnotation(node)
    self.assertTrue( self.S.isSetAnnotation() == True )
    t1 = self.S.getAnnotation()
    self.assertTrue( t1.getNumChildren() == 1 )
    self.assertTrue((  "This is a test note" == t1.getChild(0).getCharacters() ))
    if (self.S.getAnnotation() == node):
      pass
    self.S.setAnnotation(self.S.getAnnotation())
    self.assertTrue((  "This is a test note" == self.S.getAnnotation().getChild(0).getCharacters() ))
    self.S.setAnnotation(None)
    self.assertTrue( self.S.isSetAnnotation() == False )
    if (self.S.getAnnotation() != None):
      pass
    self.S.setAnnotation(node)
    self.assertTrue( self.S.isSetAnnotation() == True )
    self.S.unsetAnnotation()
    self.assertTrue( self.S.isSetAnnotation() == False )
    token = libsbml.XMLToken("(CR) &#0168; &#x00a8; &#x00A8; (NOT CR) &#; &#x; &#00a8; &#0168 &#x00a8")
    node = libsbml.XMLNode(token)
    self.S.setAnnotation(node)
    t1 = self.S.getAnnotation()
    self.assertTrue( t1.getNumChildren() == 1 )
    s = t1.getChild(0).toXMLString()
    expected =  "(CR) &#0168; &#x00a8; &#x00A8; (NOT CR) &amp;#; &amp;#x; &amp;#00a8; &amp;#0168 &amp;#x00a8";
    self.assertTrue(( expected == s ))
    token = libsbml.XMLToken("& ' > < \" &amp; &apos; &gt; &lt; &quot;")
    node = libsbml.XMLNode(token)
    self.S.setAnnotation(node)
    t1 = self.S.getAnnotation()
    self.assertTrue( t1.getNumChildren() == 1 )
    s2 = t1.getChild(0).toXMLString()
    expected2 =  "&amp; &apos; &gt; &lt; &quot; &amp; &apos; &gt; &lt; &quot;";
    self.assertTrue(( expected2 == s2 ))
    _dummyList = [ token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_setAnnotationString(self):
    annotation =  "This is a test note";
    taggedannotation =  "<annotation>This is a test note</annotation>";
    self.S.setAnnotation(annotation)
    self.assertTrue( self.S.isSetAnnotation() == True )
    if (( taggedannotation != self.S.getAnnotationString() )):
      pass
    t1 = self.S.getAnnotation()
    self.assertTrue( t1.getNumChildren() == 1 )
    self.assertTrue((  "This is a test note" == t1.getChild(0).getCharacters() ))
    self.S.setAnnotation(self.S.getAnnotationString())
    t1 = self.S.getAnnotation()
    self.assertTrue( t1.getNumChildren() == 1 )
    chars = self.S.getAnnotationString()
    self.assertTrue(( taggedannotation == chars ))
    self.S.setAnnotation( "")
    self.assertTrue( self.S.isSetAnnotation() == False )
    if (self.S.getAnnotationString() != None):
      pass
    self.S.setAnnotation(taggedannotation)
    self.assertTrue( self.S.isSetAnnotation() == True )
    if (( taggedannotation != self.S.getAnnotationString() )):
      pass
    t1 = self.S.getAnnotation()
    self.assertTrue( t1.getNumChildren() == 1 )
    t2 = t1.getChild(0)
    self.assertTrue((  "This is a test note" == t2.getCharacters() ))
    pass

  def test_SBase_setMetaId(self):
    metaid =  "x12345";
    self.S.setMetaId(metaid)
    self.assertTrue(( metaid == self.S.getMetaId() ))
    self.assertEqual( True, self.S.isSetMetaId() )
    if (self.S.getMetaId() == metaid):
      pass
    self.S.setMetaId(self.S.getMetaId())
    self.assertTrue(( metaid == self.S.getMetaId() ))
    self.S.setMetaId("")
    self.assertEqual( False, self.S.isSetMetaId() )
    if (self.S.getMetaId() != None):
      pass
    pass

  def test_SBase_setNotes(self):
    c = libsbml.Model(1,2)
    token = libsbml.XMLToken("This is a test note")
    node = libsbml.XMLNode(token)
    c.setNotes(node)
    self.assertTrue( c.isSetNotes() == True )
    if (c.getNotes() == node):
      pass
    t1 = c.getNotes()
    self.assertTrue( t1.getNumChildren() == 1 )
    self.assertTrue((  "This is a test note" == t1.getChild(0).getCharacters() ))
    c.setNotes(c.getNotes())
    t1 = c.getNotes()
    self.assertTrue( t1.getNumChildren() == 1 )
    chars = t1.getChild(0).getCharacters()
    self.assertTrue((  "This is a test note" == chars ))
    c.setNotes(None)
    self.assertTrue( c.isSetNotes() == False )
    if (c.getNotes() != None):
      pass
    c.setNotes(node)
    self.assertTrue( c.isSetNotes() == True )
    token = libsbml.XMLToken("(CR) &#0168; &#x00a8; &#x00A8; (NOT CR) &#; &#x; &#00a8; &#0168 &#x00a8")
    node = libsbml.XMLNode(token)
    c.setNotes(node)
    t1 = c.getNotes()
    self.assertTrue( t1.getNumChildren() == 1 )
    s = t1.getChild(0).toXMLString()
    expected =  "(CR) &#0168; &#x00a8; &#x00A8; (NOT CR) &amp;#; &amp;#x; &amp;#00a8; &amp;#0168 &amp;#x00a8";
    self.assertTrue(( expected == s ))
    token = libsbml.XMLToken("& ' > < \" &amp; &apos; &gt; &lt; &quot;")
    node = libsbml.XMLNode(token)
    c.setNotes(node)
    t1 = c.getNotes()
    self.assertTrue( t1.getNumChildren() == 1 )
    s2 = t1.getChild(0).toXMLString()
    expected2 =  "&amp; &apos; &gt; &lt; &quot; &amp; &apos; &gt; &lt; &quot;";
    self.assertTrue(( expected2 == s2 ))
    _dummyList = [ token ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_setNotesString(self):
    c = libsbml.Model(1,2)
    notes =  "This is a test note";
    taggednotes =  "<notes>This is a test note</notes>";
    c.setNotes(notes)
    self.assertTrue( c.isSetNotes() == True )
    if (( taggednotes != c.getNotesString() )):
      pass
    t1 = c.getNotes()
    self.assertTrue( t1.getNumChildren() == 1 )
    t2 = t1.getChild(0)
    self.assertTrue((  "This is a test note" == t2.getCharacters() ))
    c.setNotes(c.getNotesString())
    t1 = c.getNotes()
    self.assertTrue( t1.getNumChildren() == 1 )
    chars = c.getNotesString()
    self.assertTrue(( taggednotes == chars ))
    c.setNotes("")
    self.assertTrue( c.isSetNotes() == False )
    if (c.getNotesString() != None):
      pass
    c.setNotes(taggednotes)
    self.assertTrue( c.isSetNotes() == True )
    if (( taggednotes != c.getNotesString() )):
      pass
    t1 = c.getNotes()
    self.assertTrue( t1.getNumChildren() == 1 )
    t2 = t1.getChild(0)
    self.assertTrue((  "This is a test note" == t2.getCharacters() ))
    pass

  def test_SBase_setNotesString_l3(self):
    c = libsbml.Model(3,1)
    notes =  "This is a test note";
    c.setNotes(notes)
    self.assertTrue( c.isSetNotes() == False )
    pass

  def test_SBase_setNotesString_l3_addMarkup(self):
    c = libsbml.Model(3,1)
    notes =  "This is a test note";
    taggednotes = wrapString("<notes>\n" + "  <p xmlns=\"http://www.w3.org/1999/xhtml\">This is a test note</p>\n" +
    "</notes>")
    c.setNotes(notes, True)
    self.assertTrue( c.isSetNotes() == True )
    if (( taggednotes != c.getNotesString() )):
      pass
    t1 = c.getNotes()
    self.assertTrue( t1.getNumChildren() == 1 )
    t2 = t1.getChild(0)
    self.assertTrue( t2.getNumChildren() == 1 )
    t3 = t2.getChild(0)
    self.assertTrue((  "This is a test note" == t3.getCharacters() ))
    c.setNotes(c.getNotesString(), True)
    t1 = c.getNotes()
    self.assertTrue( t1.getNumChildren() == 1 )
    chars = c.getNotesString()
    self.assertTrue(( taggednotes == chars ))
    c.setNotes("", True)
    self.assertTrue( c.isSetNotes() == False )
    if (c.getNotesString() != None):
      pass
    c.setNotes(taggednotes, True)
    self.assertTrue( c.isSetNotes() == True )
    if (( taggednotes != c.getNotesString() )):
      pass
    t1 = c.getNotes()
    self.assertTrue( t1.getNumChildren() == 1 )
    t2 = t1.getChild(0)
    self.assertTrue( t2.getNumChildren() == 1 )
    t3 = t2.getChild(0)
    self.assertTrue((  "This is a test note" == t3.getCharacters() ))
    pass

  def test_SBase_unsetAnnotationWithCVTerms(self):
    annt = wrapString("<annotation>\n" +
    "  <test:test xmlns:test=\"http://test.org/test\">this is a test node</test:test>\n" +
    "</annotation>")
    annt_with_cvterm = wrapString("<annotation>\n" +
    "  <test:test xmlns:test=\"http://test.org/test\">this is a test node</test:test>\n" +
    "  <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" " +
    "xmlns:dc=\"http://purl.org/dc/elements/1.1/\" " +
    "xmlns:dcterms=\"http://purl.org/dc/terms/\" " +
    "xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" " +
    "xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" " +
    "xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n" +
    "    <rdf:Description rdf:about=\"#_000001\">\n" +
    "      <bqbiol:is>\n" +
    "        <rdf:Bag>\n" +
    "          <rdf:li rdf:resource=\"http://www.geneontology.org/#GO:0005895\"/>\n" +
    "        </rdf:Bag>\n" +
    "      </bqbiol:is>\n" +
    "    </rdf:Description>\n" +
    "  </rdf:RDF>\n" +
    "</annotation>")
    self.S.setAnnotation(annt)
    self.assertTrue( self.S.isSetAnnotation() == True )
    self.assertTrue(( annt == self.S.getAnnotationString() ))
    self.S.unsetAnnotation()
    self.assertTrue( self.S.isSetAnnotation() == False )
    self.assertTrue( self.S.getAnnotation() == None )
    self.S.setAnnotation(annt)
    self.S.setMetaId( "_000001")
    cv = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv.setBiologicalQualifierType(libsbml.BQB_IS)
    cv.addResource( "http://www.geneontology.org/#GO:0005895")
    self.S.addCVTerm(cv)
    self.assertTrue( self.S.isSetAnnotation() == True )
    self.assertTrue(( annt_with_cvterm == self.S.getAnnotationString() ))
    self.S.unsetAnnotation()
    self.assertTrue( self.S.isSetAnnotation() == False )
    self.assertTrue( self.S.getAnnotation() == None )
    _dummyList = [ cv ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_unsetAnnotationWithModelHistory(self):
    h = libsbml.ModelHistory()
    c = libsbml.ModelCreator()
    annt = wrapString("<annotation>\n" +
    "  <test:test xmlns:test=\"http://test.org/test\">this is a test node</test:test>\n" +
    "</annotation>")
    annt_with_modelhistory = wrapString("<annotation>\n" +
    "  <test:test xmlns:test=\"http://test.org/test\">this is a test node</test:test>\n" +
    "  <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" " +
    "xmlns:dc=\"http://purl.org/dc/elements/1.1/\" " +
    "xmlns:dcterms=\"http://purl.org/dc/terms/\" " +
    "xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" " +
    "xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" " +
    "xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n" +
    "    <rdf:Description rdf:about=\"#_000001\">\n" +
    "      <dc:creator>\n" +
    "        <rdf:Bag>\n" +
    "          <rdf:li rdf:parseType=\"Resource\">\n" +
    "            <vCard:N rdf:parseType=\"Resource\">\n" +
    "              <vCard:Family>Keating</vCard:Family>\n" +
    "              <vCard:Given>Sarah</vCard:Given>\n" +
    "            </vCard:N>\n" +
    "            <vCard:EMAIL>sbml-team@caltech.edu</vCard:EMAIL>\n" +
    "          </rdf:li>\n" +
    "        </rdf:Bag>\n" +
    "      </dc:creator>\n" +
    "      <dcterms:created rdf:parseType=\"Resource\">\n" +
    "        <dcterms:W3CDTF>2005-12-29T12:15:45+02:00</dcterms:W3CDTF>\n" +
    "      </dcterms:created>\n" +
    "      <dcterms:modified rdf:parseType=\"Resource\">\n" +
    "        <dcterms:W3CDTF>2005-12-30T12:15:45+02:00</dcterms:W3CDTF>\n" +
    "      </dcterms:modified>\n" +
    "    </rdf:Description>\n" +
    "  </rdf:RDF>\n" +
    "</annotation>")
    self.S.setAnnotation(annt)
    self.assertTrue( self.S.isSetAnnotation() == True )
    self.assertTrue(( annt == self.S.getAnnotationString() ))
    self.S.unsetAnnotation()
    self.assertTrue( self.S.isSetAnnotation() == False )
    self.assertTrue( self.S.getAnnotation() == None )
    self.S.setAnnotation(annt)
    self.S.setMetaId( "_000001")
    c.setFamilyName("Keating")
    c.setGivenName("Sarah")
    c.setEmail("sbml-team@caltech.edu")
    h.addCreator(c)
    dc = libsbml.Date(2005,12,29,12,15,45,1,2,0)
    h.setCreatedDate(dc)
    dm = libsbml.Date(2005,12,30,12,15,45,1,2,0)
    h.setModifiedDate(dm)
    self.S.setModelHistory(h)
    self.assertTrue( self.S.isSetAnnotation() == True )
    self.assertTrue(( annt_with_modelhistory == self.S.getAnnotationString() ))
    self.S.unsetAnnotation()
    self.assertTrue( self.S.isSetAnnotation() == False )
    self.assertTrue( self.S.getAnnotation() == None )
    _dummyList = [ c ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ h ]; _dummyList[:] = []; del _dummyList
    pass

  def test_SBase_unsetCVTerms(self):
    cv = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv.setBiologicalQualifierType(libsbml.BQB_ENCODES)
    cv.addResource( "foo")
    self.S.setMetaId( "sbase1")
    self.S.addCVTerm(cv)
    cv1 = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv1.setBiologicalQualifierType(libsbml.BQB_IS)
    cv1.addResource( "bar")
    self.S.addCVTerm(cv1)
    cv2 = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv2.setBiologicalQualifierType(libsbml.BQB_IS)
    cv2.addResource( "bar1")
    self.S.addCVTerm(cv2)
    cv4 = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv4.setBiologicalQualifierType(libsbml.BQB_IS)
    cv4.addResource( "bar1")
    self.S.addCVTerm(cv4)
    self.assertTrue( self.S.getNumCVTerms() == 2 )
    self.S.unsetCVTerms()
    self.assertTrue( self.S.getNumCVTerms() == 0 )
    #self.assertTrue( self.S.getCVTerms() == None )
    self.assertTrue( len(self.S.getCVTerms()) == 0 )
    _dummyList = [ cv ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ cv2 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ cv1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ cv4 ]; _dummyList[:] = []; del _dummyList
    pass

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestSBase))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#
# @file    TestConstraint_newSetters.py
# @brief   Constraint unit tests for new set function API
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestConstraint_newSetters.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestConstraint_newSetters(unittest.TestCase):

  global C
  C = None

  def setUp(self):
    self.C = libsbml.Constraint(2,4)
    if (self.C == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.C ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Constraint_setMath1(self):
    math = libsbml.parseFormula("2 * k")
    i = self.C.setMath(math)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.C.getMath() != math )
    self.assertEqual( True, self.C.isSetMath() )
    i = self.C.setMath(None)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.C.getMath() == None )
    self.assertEqual( False, self.C.isSetMath() )
    _dummyList = [ math ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Constraint_setMath2(self):
    math = libsbml.ASTNode(libsbml.AST_DIVIDE)
    i = self.C.setMath(math)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    self.assertEqual( False, self.C.isSetMath() )
    _dummyList = [ math ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Constraint_setMessage1(self):
    node = libsbml.XMLNode()
    i = self.C.setMessage(node)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    self.assertTrue( self.C.isSetMessage() == False )
    i = self.C.unsetMessage()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.C.isSetMessage() )
    if (self.C.getMessage() != None):
      pass    
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Constraint_setMessage2(self):
    text = libsbml.XMLNode.convertStringToXMLNode(" Some text ",None)
    triple = libsbml.XMLTriple("p", "http://www.w3.org/1999/xhtml", "")
    att = libsbml.XMLAttributes()
    xmlns = libsbml.XMLNamespaces()
    xmlns.add( "http://www.w3.org/1999/xhtml", "")
    p = libsbml.XMLNode(triple,att,xmlns)
    p.addChild(text)
    triple1 = libsbml.XMLTriple("message", "", "")
    att1 = libsbml.XMLAttributes()
    node = libsbml.XMLNode(triple1,att1)
    node.addChild(p)
    i = self.C.setMessage(node)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.C.isSetMessage() == True )
    i = self.C.unsetMessage()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.C.isSetMessage() )
    if (self.C.getMessage() != None):
      pass    
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestConstraint_newSetters))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#!/usr/bin/env python
#
# @file   generate-converters-list.py
# @brief  Generate libsbml-converters.txt, a list of SBML converter classes
# @author Michael Hucka
# @date   Created 2013-12-19
#
# This program takes one argument, the file "class-list.txt" that is assumed to
# be created by the document-creation process prior to invoking this program.
#
#<!---------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright (C) 2013-2018 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
#     3. University of Heidelberg, Heidelberg, Germany
#
# Copyright (C) 2009-2013 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
#
# Copyright (C) 2006-2008 by the California Institute of Technology,
#     Pasadena, CA, USA
#
# Copyright (C) 2002-2005 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. Japan Science and Technology Agency, Japan
#
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
#----------------------------------------------------------------------- -->*/

import sys


def main(args):
    if len(args) != 2:
        print("Must be given one argument: the path to class-list.txt")
        sys.exit(1)

    filestream = open(args[1], 'r')
    lines = filestream.read().splitlines()
    filestream.close()

    classes = [name for name in lines if name.endswith('Converter')]
    # Skip the base class name.
    classes = filter(lambda x: x != 'SBMLConverter', classes)

    print('/**')
    print(' * @class doc_list_of_libsbml_converters')
    print(' * ')
    print(' * @par')
    print(' * @li ' + '\n * @li '.join(classes))
    # Make sure to close the list with the following 3 items.  The way that
    # swigdoc.py processes class definitions chops off the /** and */, which
    # leaves nothing for swigdoc.py's @li-matching regexp to terminate its
    # match.  The extra <p> followed by a blank line does it.
    print(' * <p>')
    print(' *')
    print(' */')


if __name__ == '__main__':
    main(sys.argv)



#!/usr/bin/env python
## 
## @file    evaluateCustomMath.py
## @brief   evaluates the given formula
## @author  Frank Bergmann
## 
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS",        WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->
## 

import sys
import os.path
import libsbml

def main (args):
    """Usage: evaluateCustomMath formula [model containing values]
    """
    if len(args) < 2:
      print("Usage: evaluateCustomMath formula [model containing values]")
      return 1

    formula = args[1]
    filename = None
    if len(args) > 2:
        filename = args[2]

    math = libsbml.parseFormula(formula)
    if math is None:
      print("Invalid formula, aborting.")
      return 1

    doc = None
    if filename is not None:
      doc = libsbml.readSBML(filename)
      if doc.getNumErrors(libsbml.LIBSBML_SEV_ERROR) > 0:
        print("The models contains errors, please correct them before continuing.")
        doc.printErrors()
        return 1
      # the following maps a list of ids to their corresponding model values
      # this makes it possible to evaluate expressions involving SIds. 
      libsbml.SBMLTransforms.mapComponentValues(doc.getModel())
    else:
      # create dummy document
      doc = libsbml.SBMLDocument(3, 1)

    result = libsbml.SBMLTransforms.evaluateASTNode(math, doc.getModel())
    print("{0} = {1}".format(formula, result))


if __name__ == '__main__':
  main(sys.argv)  



#!/usr/bin/env python
##
## \file    addCVTerms.py
## \brief   adds controlled vocabulary terms to a species in a model
## \author  Sarah Keating
##
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->

import sys
import os.path
from libsbml import *

def main (args):
  """usage: addCVTerms <input-filename> <output-filename>
     Adds controlled vocabulary term to a species
  """
  if len(args) != 3:
    print(main.__doc__)
    sys.exit(2)

  d = readSBML(args[1])
  errors = d.getNumErrors()

  if errors > 0:
      print("Read Error(s):")
      d.printErrors()
      print("Correct the above and re-run.")
  else:
      n = d.getModel().getNumSpecies()

      if n <= 0:
          print("Model has no species.\n Cannot add CV terms\n")
      else:
          s = d.getModel().getSpecies(0)

          if not s.isSetMetaId(): 
            s.setMetaId('unique_id_1')
  
          cv = CVTerm()
          cv.setQualifierType(BIOLOGICAL_QUALIFIER)
          cv.setBiologicalQualifierType(BQB_IS_VERSION_OF)
          cv.addResource("http://www.geneontology.org/#GO:0005892")

          cv2 = CVTerm()
          cv2.setQualifierType(BIOLOGICAL_QUALIFIER)
          cv2.setBiologicalQualifierType(BQB_IS)
          cv2.addResource("http://www.geneontology.org/#GO:0005895")

          cv1 =  CVTerm()
          cv1.setQualifierType(BIOLOGICAL_QUALIFIER)
          cv1.setBiologicalQualifierType(BQB_IS_VERSION_OF)
          cv1.addResource("http://www.ebi.ac.uk/interpro/#IPR002394")

          s.addCVTerm(cv)
          s.addCVTerm(cv2)
          s.addCVTerm(cv1)

          writeSBML(d, args[2])

  return errors


if __name__ == '__main__':
  main(sys.argv)  



#
# @file    TestUnit.py
# @brief   Unit unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Ben Bornstein 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestUnit.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestUnit(unittest.TestCase):

  global U
  U = None

  def setUp(self):
    self.U = libsbml.Unit(2,4)
    if (self.U == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.U ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Unit_create(self):
    self.assertTrue( self.U.getTypeCode() == libsbml.SBML_UNIT )
    self.assertTrue( self.U.getMetaId() == "" )
    self.assertTrue( self.U.getNotes() == None )
    self.assertTrue( self.U.getAnnotation() == None )
    self.assertTrue( self.U.getKind() == libsbml.UNIT_KIND_INVALID )
    self.assertTrue( self.U.getExponent() == 1 )
    self.assertTrue( self.U.getScale() == 0 )
    self.assertTrue( self.U.getMultiplier() == 1.0 )
    self.assertEqual( False, self.U.isSetKind() )
    self.assertEqual( True, self.U.isSetExponent() )
    self.assertEqual( True, self.U.isSetScale() )
    self.assertEqual( True, self.U.isSetMultiplier() )
    pass  

  def test_Unit_createWithNS(self):
    xmlns = libsbml.XMLNamespaces()
    xmlns.add( "http://www.sbml.org", "testsbml")
    sbmlns = libsbml.SBMLNamespaces(2,1)
    sbmlns.addNamespaces(xmlns)
    object = libsbml.Unit(sbmlns)
    self.assertTrue( object.getTypeCode() == libsbml.SBML_UNIT )
    self.assertTrue( object.getMetaId() == "" )
    self.assertTrue( object.getNotes() == None )
    self.assertTrue( object.getAnnotation() == None )
    self.assertTrue( object.getLevel() == 2 )
    self.assertTrue( object.getVersion() == 1 )
    self.assertTrue( object.getNamespaces() != None )
    self.assertTrue( object.getNamespaces().getLength() == 2 )
    _dummyList = [ object ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Unit_free_NULL(self):
    _dummyList = [ None ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Unit_isBuiltIn(self):
    self.assertEqual( True, libsbml.Unit.isBuiltIn( "substance",1) )
    self.assertEqual( True, libsbml.Unit.isBuiltIn( "volume"   ,1) )
    self.assertEqual( False, libsbml.Unit.isBuiltIn( "area"     ,1) )
    self.assertEqual( False, libsbml.Unit.isBuiltIn( "length"   ,1) )
    self.assertEqual( True, libsbml.Unit.isBuiltIn( "time"     ,1) )
    self.assertEqual( True, libsbml.Unit.isBuiltIn( "substance",2) )
    self.assertEqual( True, libsbml.Unit.isBuiltIn( "volume"   ,2) )
    self.assertEqual( True, libsbml.Unit.isBuiltIn( "area"     ,2) )
    self.assertEqual( True, libsbml.Unit.isBuiltIn( "length"   ,2) )
    self.assertEqual( True, libsbml.Unit.isBuiltIn( "time"     ,2) )
    self.assertEqual( False, libsbml.Unit.isBuiltIn("",1) )
    self.assertEqual( False, libsbml.Unit.isBuiltIn( ""       ,1) )
    self.assertEqual( False, libsbml.Unit.isBuiltIn( "volt"   ,1) )
    self.assertEqual( False, libsbml.Unit.isBuiltIn( "foobar" ,1) )
    self.assertEqual( False, libsbml.Unit.isBuiltIn("",2) )
    self.assertEqual( False, libsbml.Unit.isBuiltIn( ""       ,2) )
    self.assertEqual( False, libsbml.Unit.isBuiltIn( "volt"   ,2) )
    self.assertEqual( False, libsbml.Unit.isBuiltIn( "foobar" ,2) )
    pass  

  def test_Unit_isXXX(self):
    self.assertEqual( False, self.U.isSetKind() )
    self.U.setKind(libsbml.UNIT_KIND_AMPERE)
    self.assertEqual( True, self.U.isAmpere() )
    self.U.setKind(libsbml.UNIT_KIND_BECQUEREL)
    self.assertEqual( True, self.U.isBecquerel() )
    self.U.setKind(libsbml.UNIT_KIND_CANDELA)
    self.assertEqual( True, self.U.isCandela() )
    self.U.setKind(libsbml.UNIT_KIND_COULOMB)
    self.assertEqual( True, self.U.isCoulomb() )
    self.U.setKind(libsbml.UNIT_KIND_DIMENSIONLESS)
    self.assertEqual( True, self.U.isDimensionless() )
    self.U.setKind(libsbml.UNIT_KIND_FARAD)
    self.assertEqual( True, self.U.isFarad() )
    self.U.setKind(libsbml.UNIT_KIND_GRAM)
    self.assertEqual( True, self.U.isGram() )
    self.U.setKind(libsbml.UNIT_KIND_GRAY)
    self.assertEqual( True, self.U.isGray() )
    self.U.setKind(libsbml.UNIT_KIND_HENRY)
    self.assertEqual( True, self.U.isHenry() )
    self.U.setKind(libsbml.UNIT_KIND_HERTZ)
    self.assertEqual( True, self.U.isHertz() )
    self.U.setKind(libsbml.UNIT_KIND_ITEM)
    self.assertEqual( True, self.U.isItem() )
    self.U.setKind(libsbml.UNIT_KIND_JOULE)
    self.assertEqual( True, self.U.isJoule() )
    self.U.setKind(libsbml.UNIT_KIND_KATAL)
    self.assertEqual( True, self.U.isKatal() )
    self.U.setKind(libsbml.UNIT_KIND_KELVIN)
    self.assertEqual( True, self.U.isKelvin() )
    self.U.setKind(libsbml.UNIT_KIND_KILOGRAM)
    self.assertEqual( True, self.U.isKilogram() )
    self.U.setKind(libsbml.UNIT_KIND_LITRE)
    self.assertEqual( True, self.U.isLitre() )
    self.U.setKind(libsbml.UNIT_KIND_LUMEN)
    self.assertEqual( True, self.U.isLumen() )
    self.U.setKind(libsbml.UNIT_KIND_LUX)
    self.assertEqual( True, self.U.isLux() )
    self.U.setKind(libsbml.UNIT_KIND_METRE)
    self.assertEqual( True, self.U.isMetre() )
    self.U.setKind(libsbml.UNIT_KIND_MOLE)
    self.assertEqual( True, self.U.isMole() )
    self.U.setKind(libsbml.UNIT_KIND_NEWTON)
    self.assertEqual( True, self.U.isNewton() )
    self.U.setKind(libsbml.UNIT_KIND_OHM)
    self.assertEqual( True, self.U.isOhm() )
    self.U.setKind(libsbml.UNIT_KIND_PASCAL)
    self.assertEqual( True, self.U.isPascal() )
    self.U.setKind(libsbml.UNIT_KIND_RADIAN)
    self.assertEqual( True, self.U.isRadian() )
    self.U.setKind(libsbml.UNIT_KIND_SECOND)
    self.assertEqual( True, self.U.isSecond() )
    self.U.setKind(libsbml.UNIT_KIND_SIEMENS)
    self.assertEqual( True, self.U.isSiemens() )
    self.U.setKind(libsbml.UNIT_KIND_SIEVERT)
    self.assertEqual( True, self.U.isSievert() )
    self.U.setKind(libsbml.UNIT_KIND_STERADIAN)
    self.assertEqual( True, self.U.isSteradian() )
    self.U.setKind(libsbml.UNIT_KIND_TESLA)
    self.assertEqual( True, self.U.isTesla() )
    self.U.setKind(libsbml.UNIT_KIND_VOLT)
    self.assertEqual( True, self.U.isVolt() )
    self.U.setKind(libsbml.UNIT_KIND_WATT)
    self.assertEqual( True, self.U.isWatt() )
    self.U.setKind(libsbml.UNIT_KIND_WEBER)
    self.assertEqual( True, self.U.isWeber() )
    pass  

  def test_Unit_set_get(self):
    u = libsbml.Unit(2,4)
    self.assertTrue( u.getKind() == libsbml.UNIT_KIND_INVALID )
    self.assertTrue( u.getExponent() == 1 )
    self.assertTrue( u.getScale() == 0 )
    self.assertTrue( u.getMultiplier() == 1.0 )
    self.assertEqual( False, u.isSetKind() )
    u.setKind(libsbml.UNIT_KIND_WATT)
    self.assertTrue( u.getKind() == libsbml.UNIT_KIND_WATT )
    u.setExponent(3)
    self.assertTrue( u.getExponent() == 3 )
    u.setScale(4)
    self.assertTrue( u.getScale() == 4 )
    u.setMultiplier(3.2)
    self.assertTrue( u.getMultiplier() == 3.2 )
    _dummyList = [ u ]; _dummyList[:] = []; del _dummyList
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestUnit))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#!/usr/bin/env python
#
#  @file    fbc_example1.py
#  @brief   SBML FBC example
#  @author  Frank Bergmann
#
# <!--------------------------------------------------------------------------
# This sample program is distributed under a different license than the rest
# of libSBML.  This program uses the open-source MIT license, as follows:
#
# Copyright (c) 2013-2018 by the California Institute of Technology
# (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
# and the University of Heidelberg (Germany), with support from the National
# Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.
#
# Neither the name of the California Institute of Technology (Caltech), nor
# of the European Bioinformatics Institute (EMBL-EBI), nor of the University
# of Heidelberg, nor the names of any contributors, may be used to endorse
# or promote products derived from this software without specific prior
# written permission.
# ------------------------------------------------------------------------ -->

from libsbml import *

sbmlns = SBMLNamespaces(3,1,"fbc",1)

#  create the document

document = SBMLDocument(sbmlns)

# mark the fbc package as not required

document.setPackageRequired("fbc", False)

#  create the Model

model= document.createModel()

#  create the Compartment

compartment = model.createCompartment()
compartment.setId("compartment")
compartment.setConstant(True)
compartment.setSize(1)

# create the Species

species = model.createSpecies()
species.setId("Node1")
species.setCompartment("compartment")
species.setBoundaryCondition(False)
species.setConstant(False)
species.setHasOnlySubstanceUnits(False)

# just as an example for setting charge and chemicalFormula

splugin = species.getPlugin("fbc")
if splugin is not None:
  splugin.setCharge(-1)
  # chemical formula should follow the hill system
  splugin.setChemicalFormula("C2H5Br")


species = model.createSpecies()
species.setId("Node2")
species.setCompartment("compartment")
species.setBoundaryCondition(False)
species.setConstant(False)
species.setHasOnlySubstanceUnits(False)

species = model.createSpecies()
species.setId("Node3")
species.setCompartment("compartment")
species.setBoundaryCondition(False)
species.setConstant(False)
species.setHasOnlySubstanceUnits(False)

species = model.createSpecies()
species.setId("Node4")
species.setCompartment("compartment")
species.setBoundaryCondition(False)
species.setConstant(False)
species.setHasOnlySubstanceUnits(False)

species = model.createSpecies()
species.setId("Node5")
species.setCompartment("compartment")
species.setBoundaryCondition(False)
species.setConstant(False)
species.setHasOnlySubstanceUnits(False)

species = model.createSpecies()
species.setId("Node6")
species.setCompartment("compartment")
species.setBoundaryCondition(False)
species.setConstant(False)
species.setHasOnlySubstanceUnits(False)

species = model.createSpecies()
species.setId("Node7")
species.setCompartment("compartment")
species.setBoundaryCondition(False)
species.setConstant(False)
species.setHasOnlySubstanceUnits(False)

species = model.createSpecies()
species.setId("Node8")
species.setCompartment("compartment")
species.setBoundaryCondition(False)
species.setConstant(False)
species.setHasOnlySubstanceUnits(False)

species = model.createSpecies()
species.setId("Node0")
species.setCompartment("compartment")
species.setBoundaryCondition(True)
species.setConstant(False)
species.setHasOnlySubstanceUnits(False)

species = model.createSpecies()
species.setId("Node9")
species.setCompartment("compartment")
species.setBoundaryCondition(True)
species.setConstant(False)
species.setHasOnlySubstanceUnits(False)

# create reactions

reaction = model.createReaction()
reaction.setId("J0")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node0")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node1")
product.setStoichiometry(1)
product.setConstant(True)

reaction = model.createReaction()
reaction.setId("J1")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node1")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node2")
product.setStoichiometry(1)
product.setConstant(True)

reaction = model.createReaction()
reaction.setId("J2")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node2")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node3")
product.setStoichiometry(1)
product.setConstant(True)

reaction = model.createReaction()
reaction.setId("J3")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node1")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node4")
product.setStoichiometry(1)
product.setConstant(True)

reaction = model.createReaction()
reaction.setId("J4")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node4")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node3")
product.setStoichiometry(1)
product.setConstant(True)

reaction = model.createReaction()
reaction.setId("J5")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node3")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node5")
product.setStoichiometry(1)
product.setConstant(True)

reaction = model.createReaction()
reaction.setId("J6")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node5")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node6")
product.setStoichiometry(1)
product.setConstant(True)

reaction = model.createReaction()
reaction.setId("J7")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node6")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node7")
product.setStoichiometry(1)
product.setConstant(True)

reaction = model.createReaction()
reaction.setId("J8")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node5")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node8")
product.setStoichiometry(1)
product.setConstant(True)

reaction = model.createReaction()
reaction.setId("J9")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node8")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node7")
product.setStoichiometry(1)
product.setConstant(True)

reaction = model.createReaction()
reaction.setId("J10")
reaction.setReversible(False)
reaction.setFast(False)
reactant = reaction.createReactant()
reactant.setSpecies("Node7")
reactant.setStoichiometry(1)
reactant.setConstant(True)
product = reaction.createProduct()
product.setSpecies("Node9")
product.setStoichiometry(1)
product.setConstant(True)

# add FBC constraints

mplugin = model.getPlugin("fbc")

bound= mplugin.createFluxBound()
bound.setId("bound1")
bound.setReaction("J0")
bound.setOperation("equal")
bound.setValue(10)

objective = mplugin.createObjective()
objective.setId("obj1")
objective.setType("maximize")

mplugin.setActiveObjectiveId("obj1")

fluxObjective = objective.createFluxObjective()
fluxObjective.setReaction("J8")
fluxObjective.setCoefficient(1)

writeSBMLToFile(document,"fbc_example1.xml")
